summaryrefslogtreecommitdiffstats
path: root/net/http/http_cache_transaction.h
diff options
context:
space:
mode:
authorrvargas@google.com <rvargas@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2012-03-20 20:42:58 +0000
committerrvargas@google.com <rvargas@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2012-03-20 20:42:58 +0000
commit40caa4c2b0101f6c0fb88db9dd82bfdb2ad8f11b (patch)
treee9f9dd8043271b1bd06ae90a1bf8370479adb814 /net/http/http_cache_transaction.h
parentf64ecd4e6610a4f1990b87be11b2d5ee41194e07 (diff)
downloadchromium_src-40caa4c2b0101f6c0fb88db9dd82bfdb2ad8f11b.zip
chromium_src-40caa4c2b0101f6c0fb88db9dd82bfdb2ad8f11b.tar.gz
chromium_src-40caa4c2b0101f6c0fb88db9dd82bfdb2ad8f11b.tar.bz2
Http cache: Restart transaction after errors reading from cached
data if we have not start validation yet. BUG=110795 TEST=net_unittests Review URL: https://chromiumcodereview.appspot.com/9734002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@127772 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/http/http_cache_transaction.h')
-rw-r--r--net/http/http_cache_transaction.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/net/http/http_cache_transaction.h b/net/http/http_cache_transaction.h
index 69cf40d..531601e 100644
--- a/net/http/http_cache_transaction.h
+++ b/net/http/http_cache_transaction.h
@@ -308,8 +308,9 @@ class HttpCache::Transaction : public HttpTransaction {
void DoneWritingToEntry(bool success);
// Returns an error to signal the caller that the current read failed. The
- // current operation |result| is also logged.
- int OnCacheReadError(int result);
+ // current operation |result| is also logged. If |restart| is true, the
+ // transaction should be restarted.
+ int OnCacheReadError(int result, bool restart);
// Deletes the current partial cache entry (sparse), and optionally removes
// the control object (partial_).